<?php

/**
 * Display a table with icons with all the sites and projects of the $user.
 */
function sentry_server_update_myprojects() {
  global $user;
  $sites = $projects = array();
  $header = array(
    t('Projects'),
  );
  // Fetch the sites of the current user and build the $header while at it.
  $result = db_query("SELECT nid FROM {node} WHERE type = 'sentry_site' AND uid = %d ORDER BY title", $user->uid);
  while ($nid = db_result($result)) {
    $node = node_load($nid);
    $header[] = l($node->title, 'node/'. $nid);
    // Do not store the whole node objects for memory consumption purposes.
    // All we need later is the projects of the sites.
    $sites[$nid] = $node->projects;
    // If we do not have info about a site's projects (eg. because it's
    // invalid), skip further processing.
    if (!is_array($node->projects)) {
      continue;
    }
    // Iterate through all the projects of a site.
    foreach ($node->projects as $project) {
      // Craft a $project_version_id that starts with the project name,
      // and contains the core version, too.
      if ($project['project_type'] == 'core') {
        $temp = explode('.', $project['version']);
        $project_version_id = 'drupal-' . $temp[0];
      }
      else {
        $temp = explode('-', $project['version']);
        $project_version_id = $project['name'] . '-' . $temp[0];
      }
      // Collect the project info without duplicates.
      $projects[$project_version_id] = array(
        'name' => $project['name'],
        'core' => $project_version_id,
      );
    }
  }
  // Sort the projects by name (but pull 'drupal' to the beginning).
  usort($projects, '_sentry_server_update_sort_projects');
  // Build the rows of the table, each row being a project and core version.
  $rows = array();
  foreach ($projects as $project) {
    // First column displays the project and core version.
    $row = array(
      l($project['core'], 'http://drupal.org/project/' . $project['name'], array('attributes' => array('target' => '_blank'))),
    );
    // Iterate through all the sites of the current user.
    foreach ($sites as $siteprojects) {
      $cell = '';
      // Iterate through all the projects of a site. If the site has the
      // project (with the appropriate core version) installed, display a
      // fancy icon with the update status. If the site does not have the
      // project installed, display an empty cell.
      if (is_array($siteprojects)) {
        foreach ($siteprojects as $siteproject) {
          if (substr($siteproject['name'] . '-' . $siteproject['version'], 0, strlen($project['core'])) == $project['core']) {
            $cell = theme('sentry_status', $siteproject, TRUE);
            // To speed things up, break out as soon as the project is found.
            break;
          }
        }
      }
      $row[] = $cell;
    }
    $rows[] = $row;
  }
  $output = theme('table', $header, $rows);
  return $output;
}

/**
 * Helper function for project sorting.
 */
function _sentry_server_update_sort_projects($a, $b) {
  if ($a['name'] == 'drupal') {
    return -1;
  }
  if ($b['name'] == 'drupal') {
    return 1;
  }
  if ($a['core'] == $b['core']) {
    return 0;
  }
  return ($a['core'] < $b['core']) ? -1 : 1;
}
